@@ -1,5 +1,6 @@
 # Copyright 2017 Palantir Technologies, Inc.
 import logging
+import traceback
 from uuid import uuid4
 
 from concurrent.futures import ThreadPoolExecutor, Future
@@ -9,11 +10,12 @@ from jsonrpc.jsonrpc2 import JSONRPC20Response, JSONRPC20Request
 from jsonrpc.exceptions import JSONRPCMethodNotFound, JSONRPCDispatchException, JSONRPCServerError
 
 log = logging.getLogger(__name__)
-
 RESPONSE_CLASS_MAP = {
     "1.0": JSONRPC10Response,
     "2.0": JSONRPC20Response
 }
+# as defined in https://github.com/Microsoft/language-server-protocol/blob/gh-pages/specification.md
+LSP_CANCEL_CODE = -32800
 
 
 class MissingMethodException(Exception):
@@ -82,7 +84,9 @@ class JSONRPCManager(object):
         """
         log.debug('Cancel request %d', request_id)
         try:
-            self._received_requests[request_id].cancel()
+            self._received_requests[request_id].set_exception(
+                JSONRPCDispatchException(code=LSP_CANCEL_CODE, message="Request cancelled")
+            )
         except KeyError:
             log.debug('Received cancel for finished/nonexistent request %d', request_id)
 
@@ -118,7 +122,7 @@ class JSONRPCManager(object):
             output = _make_response(request, error=e.error._data)
         except Exception as e:  # pylint: disable=broad-except
             log.exception('synchronous method handler exception for request: %s', request)
-            output = _make_response(request, error=JSONRPCServerError()._data)
+            output = _make_response(request, error={'code': JSONRPCServerError.CODE, 'message': traceback.format_exc()})
         else:
             if request._id in self._received_requests:
                 log.error('Received request %s with duplicate id', request.data)
@@ -147,10 +151,11 @@ class JSONRPCManager(object):
                     result = completed_future.result()
                 except JSONRPCDispatchException as e:
                     output = _make_response(request, error=e.error._data)
-                except Exception as e:  # pylint: disable=broad-except
-                    # TODO(forozco): add more descriptive error
+                except Exception:  # pylint: disable=broad-except
                     log.exception('asynchronous method handler exception for request: %s', request)
-                    output = _make_response(request, error=JSONRPCServerError()._data)
+                    output = _make_response(request, error={
+                        'code': JSONRPCServerError.CODE, 'message': traceback.format_exc()
+                    })
                 else:
                     output = _make_response(request, result=result)
                 finally:
